#    Copyright 2008, 2009 Shelby M. Tucker
#        Email:     shelby.tucker@gmail.com
#
#    This file is part of Teletory Maker.
#
#    Teletory Maker is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    Teletory Maker is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.#
#
#    You should have received a copy of the GNU General Public License
#    along with Teletory Maker.  If not, see <http://www.gnu.org/licenses/>.

from PyRTF import *

def ExportRTF(data, file, config):
    DR = Renderer()
    
    doc = Document()
    ss = doc.StyleSheet
    section = Section(break_type=Section.PAGE, first_page_number=1)
    doc.Sections.append(section)
    
    labelFont = Font(config.labelTextFont[0], config.labelTextFont[1])
    mainFont = Font(config.mainTextFont[0], config.mainTextFont[1])
    
    #Now to start making the table.
    thick_edge = BorderPS(width=30, style=BorderPS.HAIRLINE)
    thick_frame = FramePS(thick_edge, thick_edge, thick_edge, thick_edge)
    
    normal_edge = BorderPS(width=20, style=BorderPS.HAIRLINE)
    normal_frame = FramePS(normal_edge, normal_edge, normal_edge, normal_edge)
    
    table = Table(TabPS.DEFAULT_WIDTH * 4,
                   int(TabPS.DEFAULT_WIDTH * 3.5),
                   int(TabPS.DEFAULT_WIDTH * 2.5),
                   TabPS.DEFAULT_WIDTH * 3)
    
    c1 = Cell(Paragraph(TEXT('Address', font=labelFont, size=config.labelTextSize, bold=1)), thick_frame)
    c2 = Cell(Paragraph(TEXT('Name', size=config.labelTextSize, font=labelFont, bold=1)), thick_frame)
    c3 = Cell(Paragraph(TEXT('Telephone', size=config.labelTextSize, font=labelFont, bold=1)), thick_frame)
    c4 = Cell(Paragraph(TEXT('Notes', size=config.labelTextSize, font=labelFont, bold=1)), thick_frame)
    table.AddRow(c1, c2, c3, c4)
    
    for listing in data:
        c1 = Cell(Paragraph(TEXT(listing['full_address'].replace('\n', ' \\line '), size=config.mainTextSize, font=mainFont),
                            ParagraphPS(alignment=ParagraphPS.LEFT)), normal_frame)
        c2 = Cell(Paragraph(TEXT(listing['name'], size=config.mainTextSize, font=mainFont)), normal_frame)
        c3 = Cell(Paragraph(TEXT(listing['phone_num'], size=config.mainTextSize, font=mainFont)), normal_frame)
        if listing['type'] == 'work':
            c4 = Cell(Paragraph(TEXT('Business', size=config.mainTextSize, font=mainFont)), normal_frame)
        else:
            c4 = Cell(Paragraph(TEXT('')), normal_frame)
        table.AddRow(c1, c2, c3, c4)
    
    section.append(table)
    
    DR.Write(doc, open(file, 'w'))